==> mono_2.10.8.1.orig.tar.gz: mono-2.10.8.1/mcs/class/WindowsBase/System.Windows.Markup/InternalTypeHelper.cs <==
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (c) 2007 Novell, Inc. (http://www.novell.com)
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//

using System;
using System.ComponentModel;
using System.Globalization;
using System.Reflection;

namespace System.Windows.Markup {

	[EditorBrowsable (EditorBrowsableState.Never)]
	public abstract class InternalTypeHelper
	{
		protected InternalTypeHelper()
		{
		}

		protected internal abstract void AddEventHandler (EventInfo eventInfo, object target, Delegate handler);
		protected internal abstract Delegate CreateDelegate (Type delegateTYpe, object target, string handler);
		protected internal abstract object CreateInstance (Type type, CultureInfo culture);
		protected internal abstract object GetPropertyValue (PropertyInfo propertyInfo, object target, CultureInfo culture);
		protected internal abstract void SetPropertyValue (PropertyInfo propertyInfo, object target, object value, CultureInfo culture);
	}
}

==> mono_4.2.1.102+dfsg2.orig.tar.gz: mono-4.2.1+dfsg2/mcs/class/WindowsBase/System.Windows.Markup/InternalTypeHelper.cs <==
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (c) 2007 Novell, Inc. (http://www.novell.com)
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//

using System;
using System.ComponentModel;
using System.Globalization;
using System.Reflection;

namespace System.Windows.Markup {

	[EditorBrowsable (EditorBrowsableState.Never)]
	public abstract class InternalTypeHelper
	{
		protected InternalTypeHelper()
		{
		}

		protected internal abstract void AddEventHandler (EventInfo eventInfo, object target, Delegate handler);
		protected internal abstract Delegate CreateDelegate (Type delegateType, object target, string handler);
		protected internal abstract object CreateInstance (Type type, CultureInfo culture);
		protected internal abstract object GetPropertyValue (PropertyInfo propertyInfo, object target, CultureInfo culture);
		protected internal abstract void SetPropertyValue (PropertyInfo propertyInfo, object target, object value, CultureInfo culture);
	}
}
